@@ -3,7 +3,7 @@ BEGIN {
   $File::Serialize::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: DWIM file serialization/deserialization
-$File::Serialize::VERSION = '0.3.0';
+$File::Serialize::VERSION = '0.4.0';
 use 5.16.0;
 
 use feature 'current_sub';
@@ -57,9 +57,13 @@ sub _generate_serialize_file {
         my( $file, $content, $options ) = @_;
 
         $options = { %$global, %{ $options||{} } } if $global;
+        # default to utf8 => 1
+        $options->{utf8} //= 1;
 
         $file = path($file);
 
+        my $method = $options->{utf8} ? 'spew_utf8' : 'spew';
+
         my $serializer = _serializer($file, $options);
 
         $file = path( join '.', $file, $serializer->{extensions}[0] )
@@ -69,7 +73,8 @@ sub _generate_serialize_file {
                     first { $_ }
                     map( { $serializer->{$_} } qw/ options / ), sub { +{} };
         
-        $file->spew($serializer->{serialize}->($content, $options));
+
+        $file->$method($serializer->{serialize}->($content, $options));
     }
 }
 
@@ -82,6 +87,9 @@ sub _generate_deserialize_file {
         $file = path($file);
 
         $options = { %$global, %{ $options||{} } } if $global;
+        $options->{utf8} //= 1;
+
+        my $method = 'slurp' . ( '_utf8' ) x !! $options->{utf8};
 
         my $serializer = _serializer($file, $options);
 
@@ -91,8 +99,8 @@ sub _generate_deserialize_file {
         ($options) = map { $_->($options) }
                     first { $_ }
                     map( { $serializer->{$_} } qw/ options / ), sub { +{} };
-        
-        return $serializer->{deserialize}->($file->slurp, $options);
+
+        return $serializer->{deserialize}->($file->$method, $options);
     }
 }
 
@@ -169,7 +177,7 @@ File::Serialize - DWIM file serialization/deserialization
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -286,6 +294,14 @@ The serialization will be formatted for human consumption.
 
 Serializes the data using its canonical representation.
 
+=item utf8 => $boolean
+
+If set to a C<true> value, file will be read/written out using L<Path::Tiny>'s C<slurp_utf8> and C<spew_utf8>
+method ( which sets a C<binmode> of C<:encoding(UTF-8)>). Otherwise,
+L<Path::Tiny>'s C<slurp> and C<spew> methods are used.
+
+Defaults to being C<true> because, after all, it is 2015.
+
 =back
 
 =head1 FUNCTIONS
